@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
@@ -8,7 +9,7 @@ class FileMigration:
         'path': None,     # string - Source path This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
         'dest_path': None,     # string - Destination path
         'files_moved': None,     # int64 - Number of files processed
-        'files_total': None,     # int64 - Total number of files to process
+        'files_total': None,     # int64 - Deprecated: used to return a count of the applicable files.  Currently returns 0 always.  On remote servers, it is not possible to reliably determine the number of affected files for every migration operation.
         'operation': None,     # string - The type of operation
         'region': None,     # string - Region
         'status': None,     # string - Status
